def sum_two_integers(a, b):
    return a + b


def subtract_two_integers(a, b):
    return a - b


def multiply_two_integers(a, b):
    return a * b


def divide_two_integers(a, b):
    return a / b


def who_do_i_love():
    print("I love Eline")
